/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNFij for the 3D integration at all eps-orders and the alpha^0 order of the nf structure. 
 * Example: NfI3EM2 ('Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd and alpha^0 order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XNF functions to arrive at eps^-2 alpha^0. 
 */

#include <3IntNF.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

double NfI3EM2(double w,double s6,double c) {
	return ((log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 2*log(pow(1 + pow(c,2),2)))*XNF00(w,s6,0,0,c) + 2*XNF10(w,s6,0,0,c))/
   4.;
}

double NfI3EM1(double w,double s6,double c) {
	return (2*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*log(pow(1 + pow(c,2),2)) + 
        2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)))*
      XNF00(w,s6,0,0,c) + (log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 2*log(pow(1 + pow(c,2),2)))*
      XNF01(w,s6,0,0,c) + 2*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XNF10(w,s6,0,0,c) + XNF11(w,s6,0,0,c)))/4.;
}

double NfI3E0(double w,double s6,double c) {
	return (8*(log(pow(1 + pow(c,2),2))*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + 
           pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)) + 2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + 
           pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3)))*XNF00(w,s6,0,0,c) + 4*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*
           FB2(v(w),tl(s6),0,0,0,b(c)))*log(pow(1 + pow(c,2),2)) + 2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + 
           pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)))*XNF01(w,s6,0,0,c) + 
     2*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 2*log(pow(1 + pow(c,2),2)))*XNF02(w,s6,0,0,c) + 
     8*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
      XNF10(w,s6,0,0,c) + 4*log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XNF11(w,s6,0,0,c) + 4*XNF12(w,s6,0,0,c))/8.;
}

