/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNFij for the 3D integration at all eps-orders and the alpha^-1 order of the nf structure. 
 * Example: NfI3EP1AM1 ('Nf' structure, 'I'ntegration over '3' dimensions, at 'E'ps to the 'Plus '1'st and 'A'lpha to the 'M'inus '1'st order) 
 * contains logs of FXi functions evaluated at z=0,x=0,s5=0, i.e. with the deltas from all +-distributions, multiplied 
 * with the correct XNF functions to arrive at eps^1 alpha^-1. 
 */

#include <3IntNFAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

double NfI3EM2AM1(double w,double s6,double c) {
	return XNF00(w,s6,0,0,c)/2.;
}

double NfI3EM1AM1(double w,double s6,double c) {
	return (log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XNF00(w,s6,0,0,c) + XNF01(w,s6,0,0,c))/2.;
}

double NfI3E0AM1(double w,double s6,double c) {
	return (2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
      XNF00(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*XNF01(w,s6,0,0,c) + XNF02(w,s6,0,0,c))/2.;
}

double NfI3EP1AM1(double w,double s6,double c) {
	return (8*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),3) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),3))*
      XNF00(w,s6,0,0,c) + 3*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + 
           pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*XNF01(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c)))*
         XNF02(w,s6,0,0,c) + XNF03(w,s6,0,0,c)))/6.;
}
