/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNFij for the 5D integration at all eps-orders and the alpha^0 order of the pseudo-nf structure. 
 * Example: PNfI5EM1x ('P'seudo-'Nf' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'M'inus '1'st and alpha^0 order, only missing integration over 'x') 
 * contains logs of FXi functions evaluated at x=0, i.e. with only the delta from the y/x +-distribution, multiplied 
 * with the correct XPNF functions to arrive at eps^-1 alpha^0. 
 */

#include <5IntPNF.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>

/*
 * leading terms (1/eps) vanish, since that means integrating x
 * (otherwise there'd be an alpha), which has a vanishing
 * leading order in its +-dist
 */

// additional integrations run over x, s5

double PNfI5E0z(double w,double s6,double x,double s5,double c) {
	return mexp*pow(s5,-1)*pow(x,-1)*(log(FA1(v(w),tl(s6),y(x),0,0,b(c))*FA2(v(w),tl(s6),y(x),0,0,b(c))*FB1(v(w),tl(s6),y(x),0,0,b(c))*FB2(v(w),tl(s6),y(x),0,0,b(c))*
        pow(FA1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FA2(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),0,0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,0,b(c)),-1))*XPNF00(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))*pow(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),t5(s5),0,b(c)),-1))*XPNF00(w,s6,s5,0,c));
}

// additional integrations run over x, z

double PNfI5E0s(double w,double s6,double x,double z,double c) {
	return -2*mexp*pow(x,-1)*pow(z,-1)*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))*pow(FA1(v(w),tl(s6),y(x),0,0,b(c)),-1)*
        pow(FA2(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FB1(v(w),tl(s6),y(x),0,0,b(c)),-1)*pow(FB2(v(w),tl(s6),y(x),0,0,b(c)),-1))*XPNF00(w,s6,0,0,c) + 
     log(FA1(v(w),tl(s6),y(x),0,u(z),b(c))*FA2(v(w),tl(s6),y(x),0,u(z),b(c))*FB1(v(w),tl(s6),y(x),0,u(z),b(c))*FB2(v(w),tl(s6),y(x),0,u(z),b(c))*pow(FA1(v(w),tl(s6),0,0,u(z),b(c)),-1)*
        pow(FA2(v(w),tl(s6),0,0,u(z),b(c)),-1)*pow(FB1(v(w),tl(s6),0,0,u(z),b(c)),-1)*pow(FB2(v(w),tl(s6),0,0,u(z),b(c)),-1))*XPNF00(w,s6,0,z,c));
}

// additional integrations run over s5, z

double PNfI5E0x(double w,double s6,double s5,double z,double c) {
	return pow(s5,-1)*pow(z,-1)*(2*(log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))) + 2*log(pow(1 + pow(c,2),2)))*
      XPNF00(w,s6,0,0,c) - 2*log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c))*RegulA(c,z,w)*RegulB(c,z,w))*
      XPNF00(w,s6,0,z,c) - 2*(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c))) + 
        2*log(pow(1 + pow(c,2),2)))*XPNF00(w,s6,s5,0,c) + 2*log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*
        FB2(v(w),tl(s6),0,t5(s5),u(z),b(c))*RegulA(c,z,w)*RegulB(c,z,w))*XPNF00(w,s6,s5,z,c) + 4*XPNF10(w,s6,0,0,c) - 4*XPNF10(w,s6,0,z,c) - 4*XPNF10(w,s6,s5,0,c) + 4*XPNF10(w,s6,s5,z,c));
}
