/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNfij for the 5D integration at all eps-orders and the alpha^-1 order of the nf structure. 
 * Example: NfI5EP1AM1x ('Nf' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'P'lus '1'st and 'A'lpha to the 'M'inus '1'st order, only missing integration over 'x') 
 * contains logs of FXi functions evaluated at x=0, i.e. with only the delta from the y/x +-distribution, multiplied 
 * with the correct XNf functions to arrive at eps^1 alpha^-1. 
 */

#include <5IntNFAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

// additional integrations run over x, s5 irrelevant, no 1/alpha

// additional integrations run over x, z irrelevant, no 1/alpha

// additional integrations run over s5, z

double NfI5E0AM1x(double w,double s6,double s5,double z,double c) {
	return 8*pow(s5,-1)*pow(z,-1)*(XNf0(w,s6,0,0,c) - XNf0(w,s6,0,z,c) - XNf0(w,s6,s5,0,c) + XNf0(w,s6,s5,z,c));
}

double NfI5EP1AM1x(double w,double s6,double s5,double z,double c) {
	return -8*pow(s5,-1)*pow(z,-1)*((2*log(s5) + 4*log(z) - log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XNf0(w,s6,0,0,c) + 
     (-2*log(s5) - 4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),0,0,u(z),b(c))) + log(FB1(v(w),tl(s6),0,0,u(z),b(c))) + log(FB2(v(w),tl(s6),0,0,u(z),b(c))))*XNf0(w,s6,0,z,c) - 
     2*log(s5)*XNf0(w,s6,s5,0,c) - 4*log(z)*XNf0(w,s6,s5,0,c) + log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*
      XNf0(w,s6,s5,0,c) + 2*log(s5)*XNf0(w,s6,s5,z,c) + 4*log(z)*XNf0(w,s6,s5,z,c) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*
        FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XNf0(w,s6,s5,z,c) - XNf1(w,s6,0,0,c) + XNf1(w,s6,0,z,c) + XNf1(w,s6,s5,0,c) - XNf1(w,s6,s5,z,c));
}

