/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNfij for the 5D integration at all eps-orders and the alpha^-1 order of the pseudo-nf structure. 
 * Example: PNfI5EP1AM1x ('P'seudo-'Nf' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'P'lus '1'st and 'A'lpha to the 'M'inus '1'st order, only missing integration over 'x') 
 * contains logs of FXi functions evaluated at x=0, i.e. with only the delta from the y/x +-distribution, multiplied 
 * with the correct XPNf functions to arrive at eps^1 alpha^-1. 
 */

#include <5IntPNFAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>

// additional integrations run over x, s5 irrelevant, no 1/alpha

// additional integrations run over x, z irrelevant, no 1/alpha

// additional integrations run over s5, z

double PNfI5E0AM1x(double w,double s6,double s5,double z,double c) {
	return 8*pow(s5,-1)*pow(z,-1)*(XPNf0(w,s6,0,0,c) - XPNf0(w,s6,0,z,c) - XPNf0(w,s6,s5,0,c) + XPNf0(w,s6,s5,z,c));
}

double PNfI5EP1AM1x(double w,double s6,double s5,double z,double c) {
	return -8*pow(s5,-1)*pow(z,-1)*((2*log(s5) + 4*log(z) - log(FA1(v(w),tl(s6),0,0,0,b(c))*FA2(v(w),tl(s6),0,0,0,b(c))*FB1(v(w),tl(s6),0,0,0,b(c))*FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf0(w,s6,0,0,c) + 
     (-2*log(s5) - 4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),b(c))*FA2(v(w),tl(s6),0,0,u(z),b(c))*FB1(v(w),tl(s6),0,0,u(z),b(c))*FB2(v(w),tl(s6),0,0,u(z),b(c))))*XPNf0(w,s6,0,z,c) - 2*log(s5)*XPNf0(w,s6,s5,0,c) - 
     4*log(z)*XPNf0(w,s6,s5,0,c) + log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))*FA2(v(w),tl(s6),0,t5(s5),0,b(c))*FB1(v(w),tl(s6),0,t5(s5),0,b(c))*FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XPNf0(w,s6,s5,0,c) + 
     2*log(s5)*XPNf0(w,s6,s5,z,c) + 4*log(z)*XPNf0(w,s6,s5,z,c) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))*FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))*FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))*
        FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XPNf0(w,s6,s5,z,c) - XPNf1(w,s6,0,0,c) + XPNf1(w,s6,0,z,c) + XPNf1(w,s6,s5,0,c) - XPNf1(w,s6,s5,z,c));
}
