/*
 * This file contains the eps-expansion of all functions and expressions in the CA colour structure that are neither +-distributions or measurement functions 
 * (i.e. mainly structures from Jacobians and matrix element numerators, and non-divergent denominator structures), collected into one container XCA. The 
 * eps- and alpha-expansion orders of this container appear in the differences generated by +-distributions and multiply the Logs of the measurement functions. They are 
 * constructed by substitution of variables in such a way to vanish at all non-critical boundaries (i.e. boundaries that have diverging logs attached, like 
 * Log(w) at 0 or Log(1-z) at 1. As C++ sees x*Log(x) as 0*NaN, these have to be caught via if-clauses for all but the first eps- and alpha-order. The notation is such that
 * XCAij is the alpha^i eps^j order of these functions.
 */

#include <XFactorCA.h>
#include <cmath>
#include <Auxiliaries.h>
#include <Input_Common.h>
using namespace std;

double XCA0(double w,double s6,double s5,double z,double c) {
	return (1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*(1 + pow(s6,2))*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,4),-1)*pow(2 - pow(z,2),-1)*
   pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
   (-2*pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
     (1 - 2*pow(w,4)*pow(z,4)*pow(-2 + pow(z,2),2)*pow(2 - 2*pow(z,2) + pow(z,4),2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1))*
      (pow(c,2) + 2*(1 + pow(c,4))*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
        pow(c,2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)))*
   pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
   pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-1);
}

double XCA1(double w,double s6,double s5,double z,double c) {
	if(s6>=1. || s6<=0. || w<=0. || z>=1.) {
		return 0;
	} else {
		return (1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*log(pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2))*(1 + pow(s6,2))*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
   pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,4),-1)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
   (-2*pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
     (1 - 2*pow(w,4)*pow(z,4)*pow(-2 + pow(z,2),2)*pow(2 - 2*pow(z,2) + pow(z,4),2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1))*
      (pow(c,2) + 2*(1 + pow(c,4))*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
        pow(c,2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)))*
   pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
   pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-1);
	}
}

double XCA2(double w,double s6,double s5,double z,double c) {
	if(s6>=1. || s6<=0. || w<=0. || z>=1.) {
		return 0;
	} else {
		return ((1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*(1 + pow(s6,2))*pow(log(pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*
        pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
        pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
        pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2)),2)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,4),-1)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
     (-2*pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
       (1 - 2*pow(w,4)*pow(z,4)*pow(-2 + pow(z,2),2)*pow(2 - 2*pow(z,2) + pow(z,4),2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1))*
        (pow(c,2) + 2*(1 + pow(c,4))*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
          pow(c,2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)))*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-1))/2.;
	}
}

double XCA3(double w,double s6,double s5,double z,double c) {
	if(s6>=1. || s6<=0. || w<=0. || z>=1.) {
		return 0;
	} else {
		return ((1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*(1 + pow(s6,2))*pow(log(pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*
        pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
        pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
        pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2)),3)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,4),-1)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
     (-2*pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
       (1 - 2*pow(w,4)*pow(z,4)*pow(-2 + pow(z,2),2)*pow(2 - 2*pow(z,2) + pow(z,4),2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1))*
        (pow(c,2) + 2*(1 + pow(c,4))*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
          pow(c,2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)))*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-1))/6.;
	}
}

double XCA4(double w,double s6,double s5,double z,double c) {
	if(s6>=1. || s6<=0. || w<=0. || z>=1.) {
		return 0;
	} else {
		return ((1 - s6)*s6*(1 + s6)*w*(1 - z)*(1 + z)*(1 + pow(s6,2))*pow(log(pow(1 - s6,-4)*pow(s6,-4)*pow(1 + s6,-4)*pow(w,-4)*pow(1 - z,-4)*pow(1 + z,-4)*pow(2 - pow(s5,2),-1)*pow(1 + pow(s6,2),-4)*pow(2 - pow(s6,4),-1)*
        pow(2 - 2*pow(s6,4) + pow(s6,8),-1)*pow(2 - pow(z,2),-2)*pow(2 - 2*pow(z,2) + pow(z,4),-2)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
        pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)*
        pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),2)),4)*pow(2 - pow(s5,2),-1)*pow(2 - pow(s6,4),-0.5)*
     pow(2 - 2*pow(s6,4) + pow(s6,8),-0.5)*pow(1 + pow(w,4),-1)*pow(2 - pow(z,2),-1)*pow(2 - 2*pow(z,2) + pow(z,4),-1)*pow(1 + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-0.5)*
     (-2*pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
       (1 - 2*pow(w,4)*pow(z,4)*pow(-2 + pow(z,2),2)*pow(2 - 2*pow(z,2) + pow(z,4),2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1))*
        (pow(c,2) + 2*(1 + pow(c,4))*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))) + 
          pow(c,2)*pow(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),2)))*
     pow(1 + pow(c,2) - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)),-1)*
     pow(1 + pow(c,2)*(1 - (2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4)) + pow(w,4)*(2 - pow(z,2))*pow(z,2)*(2 - 2*pow(z,2) + pow(z,4))),-1))/24.;
	}
}
