#include "Auxiliaries.h"
#include <cmath>
#include <string>
#include "Input_Common.h"
#include "IntAD.h"
using namespace std;

double mexp=M(m);

double f(decimal y, decimal tl) {
	return FA1(0.5,tl,y,0.5,0.5,0.);
}

decimal u(double z) {
	return 4*pow(z,2) - 6*pow(z,4) + 4*pow(z,6) - pow(z,8);
}

decimal v(double w) {
	return pow(w,4);
}

double a(double z) {
	return 1.-pow(z,3);
}

decimal b(double c) {
	return pow(c,2.);
}

decimal t(double s) {
	return 4*pow(s,4) - 6*pow(s,8) + 4*pow(s,12) - pow(s,16);
}

decimal tl(double sl) {
	return 4*pow(sl,4) - 6*pow(sl,8) + 4*pow(sl,12) - pow(sl,16);
}

decimal y(double x) {
	return pow(x,mexp);
}

decimal Rx(double qx) {
	return qx*(3 - 3*qx + pow(qx,2));
}

decimal A(decimal u, decimal v) {
	decimal a;
	a=1.-u+u*v;
	if (a>=1.) {
		a=1.;
	} else if (a<=0.) {
		a=0.;
	}
	return a;
}

decimal T(decimal u, decimal v) {
	decimal t;
	if(u>=1.) {
		t=1.;
	} else if (u<=0) {
		t=0.;
	} else {
		t=pow(u,2)*v/(1.-u+u*v);
	}
	if (isnan(t)) {
		t=1.;
	} else if (t>=1.) {
		t=1.;
	} else if (t<=0.) {
		t=0.;
	}
	return t;
}

decimal Tk1(decimal t, decimal t5, decimal tl) {
	decimal tk1;
	if (t>=1.) {
		tk1=1-tl;
	} else if (t<=0.) {
		tk1=tl;
	} else if (tl>=1.) {
		tk1=1-t;
	} else if (tl<=0.) {
		tk1=t;
	} else {
		tk1=t + tl - 2*t*tl - 2*(t5 - 1)*sqrt((1 - t)*t*(1 - tl)*tl);
	}
	return tk1;
}

decimal Tk2(decimal t, decimal t5, decimal tl) {
	decimal tk2;
	if (t>=1.) {
		tk2=1-tl;
	} else if (t<=0.) {
		tk2=tl;
	} else if (tl>=1.) {
		tk2=1-t;
	} else if (tl<=0.) {
		tk2=t;
	} else {
		tk2=t + tl - 2*t*tl - 2*(1 - t5)*sqrt((1 - t)*t*(1 - tl)*tl);
	}
	return tk2;
}

decimal Ck1(decimal t, decimal t5, decimal tl) {
	decimal ck1;
	if (t>=1.) {
		ck1=2.*tl-1.;
	} else if (t<=0.) {
		ck1=1.-2.*tl;
	} else if (tl>=1.) {
		ck1=2.*t-1.;
	} else if (tl<=0.) {
		ck1=1.-2.*t;
	} else {
		ck1=1.-2.*(t + tl - 2*t*tl + 2*(1 - t5)*sqrt((1 - t)*t*(1 - tl)*tl));
	}
	return ck1;
}

decimal Ck2(decimal t, decimal t5, decimal tl) {
	decimal ck2;
	if (t>=1.) {
		ck2=2.*tl-1.;
	} else if (t<=0.) {
		ck2=1.-2.*tl;
	} else if (tl>=1.) {
		ck2=2.*t-1.;
	} else if (tl<=0.) {
		ck2=1.-2.*t;
	} else {
		ck2=1.-2.*(t + tl - 2*t*tl - 2*(1 - t5)*sqrt((1 - t)*t*(1 - tl)*tl));
	}
	return ck2;
}

decimal Tkcm(decimal tl, decimal t, decimal Rx) {
	decimal tki;

	if (Rx>=1.) {
		if (t>=1.) {
			tki=1-tl;
		} else if (t<=0.) {
			tki=tl;
		} else if (tl>=1.) {
			tki=1-t;
		} else if (tl<=0.) {
			tki=t;
		} else {
			tki=t + tl - 2*t*tl;
		}
		return tki;


	} else {
		if (t>=1.) {
			tki=1-tl;
		} else if (t<=0.) {
		tki=tl;
		} else if (tl>=1.) {
			tki=1-t;
		} else if (tl<=0.) {
			tki=t;
		} else {
			tki=t + tl - 2*t*tl + 2*sqrt((1 - t)*t*(1 - tl)*tl*(1 - pow(Rx,2)));
		}
		return tki;
	}
}

decimal Tkcp(decimal tl, decimal t, decimal Rx) {
	decimal tki;
	if (Rx>=1.) {
		if (t>=1.) {
			tki=1-tl;
		} else if (t<=0.) {
			tki=tl;
		} else if (tl>=1.) {
			tki=1-t;
		} else if (tl<=0.) {
			tki=t;
		} else {
			tki=t + tl - 2*t*tl;
		}
		return tki;


	} else {
		if (t>=1.) {
			tki=1-tl;
		} else if (t<=0.) {
		tki=tl;
		} else if (tl>=1.) {
			tki=1-t;
		} else if (tl<=0.) {
			tki=t;
		} else {
			tki=t + tl - 2*t*tl - 2*sqrt((1 - t)*t*(1 - tl)*tl*(1 - pow(Rx,2)));
		}
		return tki;
	}
}

decimal Cl(decimal tl) {
	return 1.-2.*tl;
}

decimal Ck(decimal tk) {
	return 1.-2.*tk;
}

//get FXi from FX to hide structures from users
double FA1(decimal v,decimal tl,decimal y,decimal t5,decimal u,decimal b) {
	return FA(v,tl,y,Tk1(T(u,v),t5,tl),u,b);
}

double FA2(decimal v,decimal tl,decimal y,decimal t5,decimal u,decimal b) {
	return FA(v,tl,y,Tk2(T(u,v),t5,tl),u,b);
}

double FB1(decimal v,decimal tl,decimal y,decimal t5,decimal u,decimal b) {
	return FB(v,tl,y,Tk1(T(u,v),t5,tl),u,b);
}

double FB2(decimal v,decimal tl,decimal y,decimal t5,decimal u,decimal b) {
	return FB(v,tl,y,Tk2(T(u,v),t5,tl),u,b);
}

//get exponent M from variable m to hide structures from users
double  M(double m) {
	double mm=2/m;
	if (isnan(mm) || isinf(mm) || mm==0. || mm<=0.) {
		return 2.;
	} else {
		return mm;
	}	
}

int ADLap(const int* ndim, const double x[], const int* ncomp, double F[],void *userdata) {
	F[0]=OL(x[0],x[1],x[2],x[3]);
	F[1]=CALap(x[0],x[1],x[2],x[3]);
	F[2]=NFLap(x[0],x[1],x[2],x[3]);
	F[3]=CFLap(x[0],x[1],x[2],x[3]);
	return 1;
}

int ADLapc(const int* ndim, const double x[], const int* ncomp, double F[],void *userdata) {
	F[0]=CFCheckLap(x[0],x[1],x[2],x[3]);
	F[1]=CFVanishLap(x[0],x[1],x[2],x[3]);
	//F[2]=CFLap(x[0],x[1],x[2],x[3]);
	return 1;
}

int ADMom(const int* ndim, const double x[],const int* ncomp, double F[],void* userdata) {
	F[0]=OL(x[0],x[1],x[2],x[3]);
	F[1]=CAMom(x[0],x[1],x[2],x[3]);
	F[2]=NFMom(x[0],x[1],x[2],x[3]);
	F[3]=CFMom(x[0],x[1],x[2],x[3]);
	return 1;
}

int ADMomc(const int* ndim, const double x[],const int* ncomp, double F[],void* userdata) {
	F[0]=CFCheckMom(x[0],x[1],x[2],x[3]);
	F[1]=CFVanishMom(x[0],x[1],x[2],x[3]);
	return 1;
}
