/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 3D integration at all eps-orders and alpha^0 order of the Cf^2 structure, subregion a. 
 * Example: I3EM2A0r ('I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd and 'A'lpha to the '0'th order, third integration over 'r' (rescaled q))  
 * contains various logs of FXi functions evaluated at x=0,c=0,s5=0, i.e. with all the deltas from +-distributions except the one associated with 'r', 
 * multiplied with the correct X functions' eps- and alpha-powers to arrive at eps^-2 alpha^0. 
 */

#include <3Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I3EM3A0r(double r, double s, double s6) {
	return 0; //poles in s5,c, can't convert x pole at leading order
}
double I3EM2A0r(double r, double s, double s6) {
	return (pow(mexp,-1)*pow(r,-1)*(-2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(r,0,s,0,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(r,0,s,0,s6)))/4.;
}
double I3EM1A0r(double r, double s, double s6) {
	return (pow(mexp,-1)*pow(r,-1)*((mexp*log(r)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0))) -
         2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)))*XCfE0A0(s,0,s6) -
      2*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE0A1(0,0,s,0,s6) +
      2*(log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE0A1(r,0,s,0,s6) +
      mexp*log(r)*(-XCfE1A0(0,0,s,0,s6) + XCfE1A0(r,0,s,0,s6)) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(r,0,s,0,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(r,0,s,0,s6)))/4.;
}
double I3E0A0r(double r, double s, double s6) {
	return (pow(mexp,-1)*pow(r,-1)*(-2*(3*mexp*log(r)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)) +
         8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),3) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),3) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),3)))*XCfE0A0(s,0,s6) -
      12*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE0A1(0,0,s,0,s6) +
      12*(pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2))*XCfE0A1(r,0,s,0,s6) -
      3*(mexp*log(r)*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0))) +
         2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2)))*XCfE1A0(0,0,s,0,s6) +
      3*(mexp*log(r)*(log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0))) +
         2*(pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2)))*XCfE1A0(r,0,s,0,s6) -
      6*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1A1(0,0,s,0,s6) +
      6*(log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE1A1(r,0,s,0,s6) - 3*mexp*log(r)*XCfE2A0(0,0,s,0,s6) +
      3*mexp*log(r)*XCfE2A0(r,0,s,0,s6) - 6*XCfE2A1(0,0,s,0,s6) + 6*XCfE2A1(r,0,s,0,s6) + 3*XCfE3A0(0,0,s,0,s6) - 3*XCfE3A0(r,0,s,0,s6)))/12.;
}

double I3EM3A0x(double x, double s, double s6) {
	return 0; //poles in s5,c, can't convert r pole at leading order
}
double I3EM2A0x(double x, double s, double s6) {
	return (pow(mexp,-1)*pow(x,-1)*(-2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(0,x,s,0,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,x,s,0,s6)))/2.;
}
double I3EM1A0x(double x, double s, double s6) {
	return (pow(mexp,-1)*pow(x,-1)*(-2*(mexp*log(x)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
            log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) +
         pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) +
         pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE0A0(s,0,s6) -
      2*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE0A1(0,0,s,0,s6) +
      2*(log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE0A1(0,x,s,0,s6) +
      2*mexp*log(x)*(-XCfE1A0(0,0,s,0,s6) + XCfE1A0(0,x,s,0,s6)) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(0,x,s,0,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,x,s,0,s6)))/2.;
}
double I3E0A0x(double x, double s, double s6) {
	return -(pow(mexp,-1)*pow(x,-1)*(4*(3*mexp*log(x)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2)) +
         4*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),3) +
            pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),3) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),3)))*XCfE0A0(s,0,s6) +
      3*(4*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE0A1(0,0,s,0,s6) +
         2*(mexp*log(x)*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
            pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE1A0(0,0,s,0,s6) +
         2*(log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1A1(0,0,s,0,s6) -
         2*(2*(pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE0A1(0,x,s,0,s6) +
            (mexp*log(x)*(log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0))) + pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) +
               pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE1A0(0,x,s,0,s6) +
            (log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE1A1(0,x,s,0,s6) +
            mexp*log(x)*(-XCfE2A0(0,0,s,0,s6) + XCfE2A0(0,x,s,0,s6))) + 2*XCfE2A1(0,0,s,0,s6) - 2*XCfE2A1(0,x,s,0,s6) - XCfE3A0(0,0,s,0,s6) + XCfE3A0(0,x,s,0,s6))))/6.;
}

double I3EM3A0c(double c, double s, double s6) {
	return 0; //two alpha poles, no c-delta to convert them, so I can only generate one eps-div via s5
}
double I3EM2A0c(double c, double s, double s6) {
	return 0; //two alpha poles, no c-delta to convert them, so I can only generate one eps-div via s5
}
double I3EM1A0c(double c, double s, double s6) {
	return 2*pow(c,-1)*pow(mexp,-2)*((-2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) +
	        pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) -
	        pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) + (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE0A1(0,0,s,0,s6));
}
double I3E0A0c(double c, double s, double s6) {
	return 2*pow(c,-1)*pow(mexp,-2)*(4*(3*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - 
           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*pow(log(c),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),3) + 
        pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),3) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3) - 
        3*log(c)*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + 
           pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2)) - 
        pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),3))*XCfE0A0(s,0,s6) - 4*(2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - 
           log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) - 
        pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + 
        pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A1(0,0,s,0,s6) + 
     2*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - 
        log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE0A2(0,0,s,0,s6) + 
     (-2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - 
           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) + 
        pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - 
        pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE1A0(0,0,s,0,s6) + (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + 
        log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE1A1(0,0,s,0,s6));
}

double I3EM3A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(XCfE0A0(s,0,s6) - XCfE0A0(s,s5,s6)))/2.;
}
double I3EM2A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(2*log(s5)*(-XCfE0A0(s,0,s6) + XCfE0A0(s,s5,s6)) - 2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(0,0,s,s5,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6)))/2.;
}
double I3EM1A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(4*XCfE0A2(0,0,s,0,s6) - 4*XCfE0A2(0,0,s,s5,s6) + 2*log(s5)*(log(s5)*(XCfE0A0(s,0,s6) - XCfE0A0(s,s5,s6)) + 2*XCfE0A1(0,0,s,0,s6) - 2*XCfE0A1(0,0,s,s5,s6) - XCfE1A0(0,0,s,0,s6) + 
          XCfE1A0(0,0,s,s5,s6)) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(0,0,s,s5,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,0,s,s5,s6)))/2.;
}
double I3E0A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*((-4*pow(log(s5),3) + 8*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),3) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),3)))*
        XCfE0A0(s,0,s6) + 4*(pow(log(s5),3) - 2*(pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),3) + 
             pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),3)))*XCfE0A0(s,s5,s6) - 3*(4*(pow(log(s5),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - 
             pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2))*XCfE0A1(0,0,s,0,s6) + 
          4*(-pow(log(s5),2) + pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2))*
           XCfE0A1(0,0,s,s5,s6) + 8*log(s5)*XCfE0A2(0,0,s,0,s6) - 4*log(FA1a(0,0,t(s),0,tl(s6),0))*XCfE0A2(0,0,s,0,s6) - 4*log(FA1b(0,0,t(s),0,tl(s6),0))*XCfE0A2(0,0,s,0,s6) - 
          4*log(FA2a(0,0,t(s),0,tl(s6),0))*XCfE0A2(0,0,s,0,s6) - 4*log(FA2b(0,0,t(s),0,tl(s6),0))*XCfE0A2(0,0,s,0,s6) - 8*log(s5)*XCfE0A2(0,0,s,s5,s6) + 4*log(FA1a(0,0,t(s),t5(s5),tl(s6),0))*XCfE0A2(0,0,s,s5,s6) + 
          4*log(FA1b(0,0,t(s),t5(s5),tl(s6),0))*XCfE0A2(0,0,s,s5,s6) + 4*log(FA2a(0,0,t(s),t5(s5),tl(s6),0))*XCfE0A2(0,0,s,s5,s6) + 4*log(FA2b(0,0,t(s),t5(s5),tl(s6),0))*XCfE0A2(0,0,s,s5,s6) - 
          2*pow(log(s5),2)*XCfE1A0(0,0,s,0,s6) + 2*pow(log(s5),2)*XCfE1A0(0,0,s,s5,s6) - 4*log(s5)*XCfE1A1(0,0,s,0,s6) + 4*log(s5)*XCfE1A1(0,0,s,s5,s6) - 4*XCfE1A2(0,0,s,0,s6) + 4*XCfE1A2(0,0,s,s5,s6) + 
          2*log(s5)*XCfE2A0(0,0,s,0,s6) - 2*log(s5)*XCfE2A0(0,0,s,s5,s6) + 2*XCfE2A1(0,0,s,0,s6) - 2*XCfE2A1(0,0,s,s5,s6) - XCfE3A0(0,0,s,0,s6) + XCfE3A0(0,0,s,s5,s6))))/6.;
}
