/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 3D integration at all eps-orders and alpha^0 order of the Cf^2 structure, subregion b. 
 * Example: I3EM2A0l ('I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd and 'A'lpha to the '0'th order, third integration over x'l')  
 * contains various logs of FXi functions evaluated at xk=0,c=0,s5=0, i.e. with all the deltas from +-distributions except the one associated with x'l', 
 * multiplied with the correct X functions' eps- and alpha-powers to arrive at eps^-2 alpha^0. 
 */

#include <3Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I3EM3A0k(double xk, double s, double s6) {
	return 0; //poles in s5,c, can't convert xl pole at leading order
}
double I3EM2A0k(double xk, double s, double s6) {
	return (pow(mexp,-1)*pow(xk,-1)*(-2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(xk,0,s,0,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(xk,0,s,0,s6)))/4.;
}
double I3EM1A0k(double xk, double s, double s6) {
	return (pow(mexp,-1)*pow(xk,-1)*(2*(mexp*log(xk)*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0))) -
	          2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2)))*XCfE0A0(s,0,s6) -
	       4*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE0A1(0,0,s,0,s6) + 4*(log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0)))*XCfE0A1(xk,0,s,0,s6) +
	       mexp*log(xk)*(-XCfE1A0(0,0,s,0,s6) + XCfE1A0(xk,0,s,0,s6)) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(xk,0,s,0,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(xk,0,s,0,s6)))/4.;
}
double I3E0A0k(double xk, double s, double s6) {
	return -(pow(mexp,-1)*pow(xk,-1)*(4*(3*mexp*log(xk)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2)) +
	           8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),3)))*XCfE0A0(s,0,s6) +
	        3*(8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2))*XCfE0A1(0,0,s,0,s6) -
	           8*(pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) + pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2))*XCfE0A1(xk,0,s,0,s6) +
	           2*(mexp*log(xk)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + 2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE1A0(0,0,s,0,s6) -
	           2*mexp*log(xk)*log(FB1(yk(xk),0,t(s),0,tl(s6),0))*XCfE1A0(xk,0,s,0,s6) - 2*mexp*log(xk)*log(FB2(yk(xk),0,t(s),0,tl(s6),0))*XCfE1A0(xk,0,s,0,s6) -
	           4*pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2)*XCfE1A0(xk,0,s,0,s6) - 4*pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2)*XCfE1A0(xk,0,s,0,s6) +
	           4*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1A1(0,0,s,0,s6) - 4*log(FB1(yk(xk),0,t(s),0,tl(s6),0))*XCfE1A1(xk,0,s,0,s6) -
	           4*log(FB2(yk(xk),0,t(s),0,tl(s6),0))*XCfE1A1(xk,0,s,0,s6) + mexp*log(xk)*XCfE2A0(0,0,s,0,s6) - mexp*log(xk)*XCfE2A0(xk,0,s,0,s6) + 2*XCfE2A1(0,0,s,0,s6) - 2*XCfE2A1(xk,0,s,0,s6) - XCfE3A0(0,0,s,0,s6) +
	           XCfE3A0(xk,0,s,0,s6))))/12.;
}

double I3EM3A0l(double xl, double s, double s6) {
	return 0; //poles in s5,c, can't convert xk pole at leading order
}
double I3EM2A0l(double xl, double s, double s6) {
	return (pow(mexp,-1)*pow(xl,-1)*(-2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(0,xl,s,0,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,xl,s,0,s6)))/4.;
}
double I3EM1A0l(double xl, double s, double s6) {
	return (pow(mexp,-1)*pow(xl,-1)*(2*(mexp*log(xl)*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0))) -
	          2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2)))*XCfE0A0(s,0,s6) -
	       4*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE0A1(0,0,s,0,s6) + 4*(log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0)))*XCfE0A1(0,xl,s,0,s6) +
	       mexp*log(xl)*(-XCfE1A0(0,0,s,0,s6) + XCfE1A0(0,xl,s,0,s6)) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(0,xl,s,0,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,xl,s,0,s6)))/4.;
}
double I3E0A0l(double xl, double s, double s6) {
	return -(pow(mexp,-1)*pow(xl,-1)*(4*(3*mexp*log(xl)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2)) +
	           8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),3)))*XCfE0A0(s,0,s6) +
	        3*(8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2))*XCfE0A1(0,0,s,0,s6) -
	           8*(pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) + pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2))*XCfE0A1(0,xl,s,0,s6) +
	           2*(mexp*log(xl)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + 2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE1A0(0,0,s,0,s6) -
	           2*mexp*log(xl)*log(FB1(0,yl(xl),t(s),0,tl(s6),0))*XCfE1A0(0,xl,s,0,s6) - 2*mexp*log(xl)*log(FB2(0,yl(xl),t(s),0,tl(s6),0))*XCfE1A0(0,xl,s,0,s6) -
	           4*pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2)*XCfE1A0(0,xl,s,0,s6) - 4*pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2)*XCfE1A0(0,xl,s,0,s6) +
	           4*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1A1(0,0,s,0,s6) - 4*log(FB1(0,yl(xl),t(s),0,tl(s6),0))*XCfE1A1(0,xl,s,0,s6) -
	           4*log(FB2(0,yl(xl),t(s),0,tl(s6),0))*XCfE1A1(0,xl,s,0,s6) + mexp*log(xl)*XCfE2A0(0,0,s,0,s6) - mexp*log(xl)*XCfE2A0(0,xl,s,0,s6) + 2*XCfE2A1(0,0,s,0,s6) - 2*XCfE2A1(0,xl,s,0,s6) - XCfE3A0(0,0,s,0,s6) +
	           XCfE3A0(0,xl,s,0,s6))))/12.;
}

double I3EM3A0c(double c, double s, double s6) {
	return 0; //two alpha poles, no c-delta to convert them, so I can only generate one eps-div via s5
}
double I3EM2A0c(double c, double s, double s6) {
	return 0; //two alpha poles, no c-delta to convert them, so I can only generate one eps-div via s5
}
double I3EM1A0c(double c, double s, double s6) {
	return 4*pow(c,-1)*pow(mexp,-2)*((2*log(c)*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),b(c)))) + pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) -
	        pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) +
	     (log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE0A1(0,0,s,0,s6));
}
double I3E0A0c(double c, double s, double s6) {
	return 4*pow(c,-1)*pow(mexp,-2)*(4*(3*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*pow(log(c),2) + 
        pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) + 
        3*log(c)*(-pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2)) - 
        pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),3))*XCfE0A0(s,0,s6) - 4*(2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c)))) - 
        pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A1(0,0,s,0,s6) + 
     2*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE0A2(0,0,s,0,s6) - 
     (2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c)))) - pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + 
        pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*XCfE1A0(0,0,s,0,s6) + 
     (log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE1A1(0,0,s,0,s6));
}

double I3EM3A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(XCfE0A0(s,0,s6) - XCfE0A0(s,s5,s6)))/2.;
}
double I3EM2A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(2*log(s5)*(-XCfE0A0(s,0,s6) + XCfE0A0(s,s5,s6)) - 2*XCfE0A1(0,0,s,0,s6) + 2*XCfE0A1(0,0,s,s5,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6)))/2.;
}
double I3EM1A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(4*XCfE0A2(0,0,s,0,s6) - 4*XCfE0A2(0,0,s,s5,s6) + 2*log(s5)*(log(s5)*(XCfE0A0(s,0,s6) - XCfE0A0(s,s5,s6)) + 2*XCfE0A1(0,0,s,0,s6) - 2*XCfE0A1(0,0,s,s5,s6) - XCfE1A0(0,0,s,0,s6) + 
          XCfE1A0(0,0,s,s5,s6)) - 2*XCfE1A1(0,0,s,0,s6) + 2*XCfE1A1(0,0,s,s5,s6) + XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,0,s,s5,s6)))/2.;
}
double I3E0A0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(s5,-1)*(-4*(pow(log(s5),3) - 4*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3)))*XCfE0A0(s,0,s6) + 
       4*(pow(log(s5),3) - 4*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),3)))*XCfE0A0(s,s5,s6) - 
       3*(4*(pow(log(s5),2) - 2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE0A1(0,0,s,0,s6) + 
          (-4*pow(log(s5),2) + 8*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)))*XCfE0A1(0,0,s,s5,s6) + 8*log(s5)*XCfE0A2(0,0,s,0,s6) - 
          8*log(FB1(0,0,t(s),0,tl(s6),0))*XCfE0A2(0,0,s,0,s6) - 8*log(FB2(0,0,t(s),0,tl(s6),0))*XCfE0A2(0,0,s,0,s6) - 8*log(s5)*XCfE0A2(0,0,s,s5,s6) + 8*log(FB1(0,0,t(s),t5(s5),tl(s6),0))*XCfE0A2(0,0,s,s5,s6) + 
          8*log(FB2(0,0,t(s),t5(s5),tl(s6),0))*XCfE0A2(0,0,s,s5,s6) - 2*pow(log(s5),2)*XCfE1A0(0,0,s,0,s6) + 2*pow(log(s5),2)*XCfE1A0(0,0,s,s5,s6) - 4*log(s5)*XCfE1A1(0,0,s,0,s6) + 4*log(s5)*XCfE1A1(0,0,s,s5,s6) - 
          4*XCfE1A2(0,0,s,0,s6) + 4*XCfE1A2(0,0,s,s5,s6) + 2*log(s5)*XCfE2A0(0,0,s,0,s6) - 2*log(s5)*XCfE2A0(0,0,s,s5,s6) + 2*XCfE2A1(0,0,s,0,s6) - 2*XCfE2A1(0,0,s,s5,s6) - XCfE3A0(0,0,s,0,s6) + XCfE3A0(0,0,s,s5,s6)
          )))/6.;
}
