/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 3D integration at all eps-orders and alpha^-2 order of the Cf^2 structure, subregion b. 
 * Example: I3EM1AM2l ('I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '1'st and 'A'lpha to the 'M'inus '2'nd order, third integration over x'l')  
 * contains various logs of FXi functions evaluated at xk=0,c=0,s5=0, i.e. with all the deltas from +-distributions except the one associated with x'l', 
 * multiplied with the correct X functions' eps- and alpha-powers to arrive at eps^-1 alpha^-2. 
 */

#include <3IntAM2.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

//only xi generate alpha poles
double I3EM1AM2k(double xk, double s, double s6) {
	return 0;
}
double I3E0AM2k(double xk, double s, double s6) {
	return 0;
}
double I3E1AM2k(double xk, double s, double s6) {
	return 0;
}
double I3E2AM2k(double xk, double s, double s6) {
	return 0;
}

//only xi generate alpha poles
double I3EM1AM2l(double xl, double s, double s6) {
	return 0;
}
double I3E0AM2l(double xl, double s, double s6) {
	return 0;
}
double I3E1AM2l(double xl, double s, double s6) {
	return 0;
}
double I3E2AM2l(double xl, double s, double s6) {
	return 0;
}

double I3EM1AM2c(double c, double s, double s6) {
	return 0; //two alpha poles, one eps pole via s5, leading order in all others -> vanish due to exponent
}
double I3E0AM2c(double c, double s, double s6) {
	return 8*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-2)*XCfE0A0(s,0,s6);
}
double I3E1AM2c(double c, double s, double s6) {
	return -8*pow(c,-1)*pow(mexp,-2)*(2*(2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c)))) - pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) +
	     (-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE1A0(0,0,s,0,s6));
}
double I3E2AM2c(double c, double s, double s6) {
	return (8*pow(c,-1)*pow(mexp,-2)*(8*(3*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*pow(log(c),2) +
	          pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) -
	          3*log(c)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2)) -
	          pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),3))*XCfE0A0(s,0,s6) - 3*(2*(2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) -
	                log(FB2(0,0,t(s),0,tl(s6),b(c)))) - pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*
	           XCfE1A0(0,0,s,0,s6) + (-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),b(c))))*XCfE2A0(0,0,s,0,s6))))/3.;
}

double I3EM1AM2s(double s, double s5, double s6) {
	return 2*pow(mexp,-2)*pow(s5,-1)*(XCfE0A0(s,0,s6) - XCfE0A0(s,s5,s6));
}
double I3E0AM2s(double s, double s5, double s6) {
	return 2*pow(mexp,-2)*pow(s5,-1)*(2*(-log(s5) + log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE0A0(s,0,s6) +
		     2*(log(s5) - log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE0A0(s,s5,s6) + XCfE1A0(0,0,s,0,s6) - XCfE1A0(0,0,s,s5,s6));
}
double I3E1AM2s(double s, double s5, double s6) {
	return 2*pow(mexp,-2)*pow(s5,-1)*(2*(-2*log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + pow(log(s5),2) + 2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*
		      XCfE0A0(s,0,s6) - 2*(-2*log(s5)*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0))) + pow(log(s5),2) +
		        2*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)))*XCfE0A0(s,s5,s6) +
		     2*(-log(s5) + log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1A0(0,0,s,0,s6) + 2*(log(s5) - log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1A0(0,0,s,s5,s6) +
		     XCfE2A0(0,0,s,0,s6) - XCfE2A0(0,0,s,s5,s6));
}
double I3E2AM2s(double s, double s5, double s6) {
	return (-2*pow(mexp,-2)*pow(s5,-1)*(4*(-3*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*pow(log(s5),2) + pow(log(s5),3) +
	          6*log(s5)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)) - 4*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3)))*XCfE0A0(s,0,s6) -
	       4*(-3*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*pow(log(s5),2) + pow(log(s5),3) +
	          6*log(s5)*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)) - 4*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),3)))*
	        XCfE0A0(s,s5,s6) - 3*(2*(-2*log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + pow(log(s5),2) + 2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*
	           XCfE1A0(0,0,s,0,s6) - 2*(-2*log(s5)*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0))) + pow(log(s5),2) +
	             2*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)))*XCfE1A0(0,0,s,s5,s6) +
	          2*(-log(s5) + log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE2A0(0,0,s,0,s6) +
	          2*(log(s5) - log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE2A0(0,0,s,s5,s6) + XCfE3A0(0,0,s,0,s6) - XCfE3A0(0,0,s,s5,s6))))/3.;
}
